==> zbxe.beta.0.2.1.tgz: zbxe/modules/blog/lang/en.lang.php <==
<?php
    /**
     * @file   en.lang.php
     * @author zero (zero@nzeo.com)
     * @brief  Basic language pack for blog module
     **/

    // Words used in button
    $lang->cmd_blog_list = 'Blog List';
    $lang->cmd_module_config = 'Common blog setting';
    $lang->cmd_view_info = 'Blog Info';
    $lang->cmd_manage_menu = 'Menu management';
    $lang->cmd_make_child = 'Add child category';
    $lang->cmd_enable_move_category = "Change category position (Drag the top menu after selection)";
    $lang->cmd_remake_cache = 'Rebuild cache file';
    $lang->cmd_layout_setup = 'Configure layout';
    $lang->cmd_layout_edit = 'Edit layout';

    // Item
    $lang->parent_category_name = 'Parent category';
    $lang->category_name = 'Category';
    $lang->expand = 'Expand';
    $lang->category_group_srls = 'Accessable Group';
    $lang->search_result = 'Search result';
    
    // blah blah..
    $lang->about_category_name = 'Please input category name';
    $lang->about_expand = 'By selecting this option, it will be always expanded';
    $lang->about_category_group_srls = 'Only the selected group will be able to see current categories. (Manually open xml file to expose)';
    $lang->about_layout_setup = 'You can manually modify blog layout code. Insert or manage the widget code anywhere you want';
    $lang->about_blog_category = 'You can make blog categories.<br />When blog category is broken, try rebuilding the cache file manually.';
    $lang->about_blog = "This is a blog module that can create and manage blog.\nAfter creating a blog, please decorate your blog by category and skin management because this blog module uses layout that is included in the blog skin.\nIf you want to connect other boards inside the blog, use the menu module to create a menu and then connect it with the skin manager";
?>

==> zbxe.beta.0.2.7.tgz: zbxe/modules/blog/lang/en.lang.php <==
<?php
    /**
     * @file   en.lang.php
     * @author zero (zero@nzeo.com)
     * @brief  Basic language pack for blog module
     **/

    // Words used in button
    $lang->cmd_blog_list = 'Blog List';
    $lang->cmd_module_config = 'Common blog setting';
    $lang->cmd_view_info = 'Blog Info';
    $lang->cmd_manage_menu = 'Menu management';
    $lang->cmd_make_child = 'Add child category';
    $lang->cmd_enable_move_category = "Change category position (Drag the top menu after selection)";
    $lang->cmd_remake_cache = 'Rebuild cache file';
    $lang->cmd_layout_setup = 'Configure layout';
    $lang->cmd_layout_edit = 'Edit layout';

    // Item
    $lang->parent_category_title = 'Parent category';
    $lang->category_title = 'Category';
    $lang->expand = 'Expand';
    $lang->category_group_srls = 'Accessable Group';
    $lang->search_result = 'Search result';
    
    // blah blah..
    $lang->about_category_title = 'Please input category name';
    $lang->about_expand = 'By selecting this option, it will be always expanded';
    $lang->about_category_group_srls = 'Only the selected group will be able to see current categories. (Manually open xml file to expose)';
    $lang->about_layout_setup = 'You can manually modify blog layout code. Insert or manage the widget code anywhere you want';
    $lang->about_blog_category = 'You can make blog categories.<br />When blog category is broken, try rebuilding the cache file manually.';
    $lang->about_blog = "This is a blog module that can create and manage blog.\nAfter creating a blog, please decorate your blog by category and skin management because this blog module uses layout that is included in the blog skin.\nIf you want to connect other boards inside the blog, use the menu module to create a menu and then connect it with the skin manager";
?>
